function getValue(id) {
  return document.getElementById(id).value;
}

function setValue(id, value) {
  document.getElementById(id).value = value;
}

function displayMessage(msg) {
  document.getElementById("message").innerHTML = msg;
}

function displayError(error) {
  document.getElementById("error").innerHTML = JSON.stringify(error);
}

function handleAjaxError(error) {
  displayError(error);

  switch (error.status) {
    case 404:
      console.log(error.responseText);
      break;
    case 500:
      console.log(error.responseText);
      break;
    default:
      console.log(error);
      break;
  }
}

function ajax(verb, url, data, resolve, reject) {
  // Create XMLHttpRequest object
  let req = new XMLHttpRequest();

  // When the entire request fails it is probably a network error
  req.onerror = function () {
    if(reject) {
      reject(new Error('There was a network error.'));
    }
  };

  // Setup state change event
  req.onreadystatechange = function () {
    if (this.readyState === XMLHttpRequest.DONE) {
      // Check status property to see what is going on
      if (this.status >= 200 && this.status < 400) {
        if (resolve) {
          resolve(JSON.parse(this.response));
        }
      } else if (this.status >= 400) {
        if(reject) {
          reject({
            "status": this.status,
            "statusText": this.statusText,
            "response": this.response,
            "responseText": this.responseText
          });
        }
      }
    }
  };

  // Open Request
  req.open(verb, url);

  // Set headers for JSON
  req.setRequestHeader("Content-Type", "application/json");

  // Check to see if we need to pass data
  if (data) {
    // Submit the request with data
    req.send(JSON.stringify(data));
  }
  else {
    // Submit the request
    req.send();
  }
}
